@@ -8,6 +8,7 @@ use crate::http::url::DinoparcUrls;
 use ::scraper::Html;
 use ::url::Url;
 use async_trait::async_trait;
+use encoding_rs::ISO_8859_15;
 use erased_serde::Serialize as ErasedSerialize;
 use etwin_core::clock::Clock;
 use etwin_core::dinoparc::{
@@ -19,15 +20,16 @@ use etwin_core::types::AnyError;
 use etwin_log::Logger;
 use etwin_serde_tools::{serialize_header_map, serialize_status_code, serialize_url};
 use md5::{Digest, Md5};
-use reqwest::header::HeaderMap;
+use reqwest::header::{HeaderMap, HeaderValue, CONTENT_TYPE};
 use reqwest::{Client, RequestBuilder, Response, StatusCode};
 use serde::Serialize;
+use std::borrow::Cow;
 use std::convert::TryInto;
 use std::fmt::Debug;
 use std::fs;
 use std::path::PathBuf;
 use std::str::FromStr;
-use std::sync::atomic::{AtomicU64, Ordering};
+use std::sync::atomic::{AtomicBool, AtomicU64, Ordering};
 use std::time::Duration;
 
 const USER_AGENT: &str = "EtwinDinoparcScraper";
@@ -271,7 +273,7 @@ where
     match server {
       DinoparcServer::DinoparcCom => ["71".parse().unwrap(), "72".parse().unwrap()],
       DinoparcServer::EnDinoparcCom => ["1".parse().unwrap(), "2".parse().unwrap()],
-      DinoparcServer::SpDinoparcCom => ["2".parse().unwrap(), "1".parse().unwrap()],
+      DinoparcServer::SpDinoparcCom => ["3".parse().unwrap(), "1".parse().unwrap()],
     }
   }
 
@@ -287,16 +289,21 @@ where
     let urls = DinoparcUrls::new(options.server);
 
     let now = self.clock.now();
-    let res = self
+    let form = encode_form(&LoginForm {
+      login: options.username.as_str(),
+      pass: options.password.as_str(),
+    })?;
+
+    let req = self
       .client
       .post(urls.login())
-      .form(&LoginForm {
-        login: options.username.as_str(),
-        pass: options.password.as_str(),
-      })
-      .send()
-      .await
-      .log_on_err(event, logger)?;
+      .header(
+        CONTENT_TYPE,
+        HeaderValue::from_static("application/x-www-form-urlencoded"),
+      )
+      .body(form);
+
+    let res = req.send().await.log_on_err(event, logger)?;
     event.state = "login_response";
     let login_res_meta = HttpResponseMeta::from(&res);
     event.login_response = Some(&login_res_meta);
@@ -563,3 +570,28 @@ impl<Ok, Err: Debug> ResultExt for Result<Ok, Err> {
     }
   }
 }
+
+fn encode_form<T: Serialize + ?Sized>(form: &T) -> Result<String, AnyError> {
+  let had_encoding_errors = AtomicBool::new(false);
+  let form = form_with_encoding(form, |s| {
+    let (bytes, encoding, errors) = ISO_8859_15.encode(s);
+    if encoding != ISO_8859_15 || errors {
+      had_encoding_errors.store(true, Ordering::SeqCst);
+    }
+    bytes
+  })?;
+  if had_encoding_errors.load(Ordering::SeqCst) {
+    return Err("encoding error".into());
+  }
+  Ok(form)
+}
+
+fn form_with_encoding<T: Serialize + ?Sized>(
+  form: &T,
+  encoding: impl Fn(&str) -> Cow<[u8]>,
+) -> Result<String, serde_urlencoded::ser::Error> {
+  let mut urlencoder = form_urlencoded::Serializer::new("".to_owned());
+  urlencoder.encoding_override(Some(&encoding));
+  form.serialize(serde_urlencoded::Serializer::new(&mut urlencoder))?;
+  Ok(urlencoder.finish())
+}
